# Orquestra


Orquestra implements a layout environment to accommodate Pyforms applications. The examples shown on this documentation are based on the orquestra environment, but one can be replaced by any other layout environment.


https://pyforms-web.readthedocs.io